import './NewGame.css';
import React from 'react';
import { AppData } from '../../context/data'
import { AppContext } from '../../context/app'
import { useLocation, matchPath } from "react-router";
import { SelectPlayer } from './Player';
import { WhiteStone, BlackStone } from './Stone';


export default function NewGame() {
  const [ctx, dispatchCtx] = React.useContext(AppContext)
  const [data] = React.useContext(AppData)
  const { pathname } = useLocation();
  const isMyPath = matchPath("/game/new", pathname);

  if (!isMyPath)
    return

  const nameOptions = data.leaderboard
    ? Object.keys(data.leaderboard).map(playerName => {
      const displayName = data.isCurrentUser(playerName) ? 'You' : playerName
      return <option key={playerName} value={playerName}>{displayName}</option>
    })
    : []

  const whiteOptions = Array(nameOptions)
  whiteOptions.push(<option key='default' value=''>{'select …'}</option>)

  const blackOptions = Array(nameOptions)
  blackOptions.push(<option key='default' value=''>{'select …'}</option>)

  const setWhitePlayer = (name) => {
    dispatchCtx({ component: "new-game", whitePlayer: name })
  }

  const setBlackPlayer = (name) => {
    dispatchCtx({ component: "new-game", blackPlayer: name })
  }

  return (
    <div className='new-game'>
      <div>
        <WhiteStone/>
        <SelectPlayer name={ctx.newGame.whitePlayer} setName={setWhitePlayer} nameOptions={whiteOptions} />
      </div>
      <div>- vs -</div>
      <div>
        <SelectPlayer name={ctx.newGame.blackPlayer} setName={setBlackPlayer} nameOptions={blackOptions} />
        <BlackStone/>
      </div>
    </div>
  )
}